==> libqhull-devel-2019.1-1.tar.xz: usr/lib/cmake/Qhull/QhullTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qhull::qhullcpp" for configuration "RelWithDebInfo"
set_property(TARGET Qhull::qhullcpp APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qhull::qhullcpp PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELWITHDEBINFO "CXX"
  IMPORTED_LOCATION_RELWITHDEBINFO "/usr/lib/libqhullcpp.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhullcpp )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhullcpp "/usr/lib/libqhullcpp.a" )

# Import target "Qhull::qhullstatic" for configuration "RelWithDebInfo"
set_property(TARGET Qhull::qhullstatic APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qhull::qhullstatic PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELWITHDEBINFO "C"
  IMPORTED_LOCATION_RELWITHDEBINFO "/usr/lib/libqhullstatic.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhullstatic )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhullstatic "/usr/lib/libqhullstatic.a" )

# Import target "Qhull::qhullstatic_r" for configuration "RelWithDebInfo"
set_property(TARGET Qhull::qhullstatic_r APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qhull::qhullstatic_r PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELWITHDEBINFO "C"
  IMPORTED_LOCATION_RELWITHDEBINFO "/usr/lib/libqhullstatic_r.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhullstatic_r )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhullstatic_r "/usr/lib/libqhullstatic_r.a" )

# Import target "Qhull::qhull_r" for configuration "RelWithDebInfo"
set_property(TARGET Qhull::qhull_r APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qhull::qhull_r PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "/usr/lib/libqhull_r.dll.a"
  IMPORTED_LOCATION_RELWITHDEBINFO "/usr/bin/cygqhull_r-7.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhull_r )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhull_r "/usr/lib/libqhull_r.dll.a" "/usr/bin/cygqhull_r-7.dll" )

# Import target "Qhull::qhull" for configuration "RelWithDebInfo"
set_property(TARGET Qhull::qhull APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qhull::qhull PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "/usr/bin/qhull.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhull )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhull "/usr/bin/qhull.exe" )

# Import target "Qhull::rbox" for configuration "RelWithDebInfo"
set_property(TARGET Qhull::rbox APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qhull::rbox PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "/usr/bin/rbox.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::rbox )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::rbox "/usr/bin/rbox.exe" )

# Import target "Qhull::qconvex" for configuration "RelWithDebInfo"
set_property(TARGET Qhull::qconvex APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qhull::qconvex PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "/usr/bin/qconvex.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qconvex )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qconvex "/usr/bin/qconvex.exe" )

# Import target "Qhull::qdelaunay" for configuration "RelWithDebInfo"
set_property(TARGET Qhull::qdelaunay APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qhull::qdelaunay PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "/usr/bin/qdelaunay.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qdelaunay )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qdelaunay "/usr/bin/qdelaunay.exe" )

# Import target "Qhull::qvoronoi" for configuration "RelWithDebInfo"
set_property(TARGET Qhull::qvoronoi APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qhull::qvoronoi PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "/usr/bin/qvoronoi.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qvoronoi )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qvoronoi "/usr/bin/qvoronoi.exe" )

# Import target "Qhull::qhalf" for configuration "RelWithDebInfo"
set_property(TARGET Qhull::qhalf APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qhull::qhalf PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "/usr/bin/qhalf.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhalf )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhalf "/usr/bin/qhalf.exe" )

# Import target "Qhull::libqhull" for configuration "RelWithDebInfo"
set_property(TARGET Qhull::libqhull APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qhull::libqhull PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "/usr/lib/libqhull.dll.a"
  IMPORTED_LOCATION_RELWITHDEBINFO "/usr/bin/cygqhull-7.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::libqhull )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::libqhull "/usr/lib/libqhull.dll.a" "/usr/bin/cygqhull-7.dll" )

# Import target "Qhull::qhull_p" for configuration "RelWithDebInfo"
set_property(TARGET Qhull::qhull_p APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qhull::qhull_p PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "/usr/lib/libqhull_p.dll.a"
  IMPORTED_LOCATION_RELWITHDEBINFO "/usr/bin/cygqhull_p-7.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhull_p )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhull_p "/usr/lib/libqhull_p.dll.a" "/usr/bin/cygqhull_p-7.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> libqhull-devel-2020.2-1.tar.xz: usr/lib/cmake/Qhull/QhullTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qhull::qhull" for configuration "RelWithDebInfo"
set_property(TARGET Qhull::qhull APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qhull::qhull PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/qhull.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhull )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhull "${_IMPORT_PREFIX}/bin/qhull.exe" )

# Import target "Qhull::rbox" for configuration "RelWithDebInfo"
set_property(TARGET Qhull::rbox APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qhull::rbox PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/rbox.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::rbox )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::rbox "${_IMPORT_PREFIX}/bin/rbox.exe" )

# Import target "Qhull::qconvex" for configuration "RelWithDebInfo"
set_property(TARGET Qhull::qconvex APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qhull::qconvex PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/qconvex.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qconvex )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qconvex "${_IMPORT_PREFIX}/bin/qconvex.exe" )

# Import target "Qhull::qdelaunay" for configuration "RelWithDebInfo"
set_property(TARGET Qhull::qdelaunay APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qhull::qdelaunay PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/qdelaunay.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qdelaunay )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qdelaunay "${_IMPORT_PREFIX}/bin/qdelaunay.exe" )

# Import target "Qhull::qvoronoi" for configuration "RelWithDebInfo"
set_property(TARGET Qhull::qvoronoi APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qhull::qvoronoi PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/qvoronoi.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qvoronoi )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qvoronoi "${_IMPORT_PREFIX}/bin/qvoronoi.exe" )

# Import target "Qhull::qhalf" for configuration "RelWithDebInfo"
set_property(TARGET Qhull::qhalf APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qhull::qhalf PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/qhalf.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhalf )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhalf "${_IMPORT_PREFIX}/bin/qhalf.exe" )

# Import target "Qhull::qhull_r" for configuration "RelWithDebInfo"
set_property(TARGET Qhull::qhull_r APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qhull::qhull_r PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libqhull_r.dll.a"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/cygqhull_r-8.0.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhull_r )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhull_r "${_IMPORT_PREFIX}/lib/libqhull_r.dll.a" "${_IMPORT_PREFIX}/bin/cygqhull_r-8.0.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
